Svg

Struct Svg 

pub struct Svg { /* private fields */ }
A vector graphics image.

An Svg image resizes smoothly without losing any quality.

Svg images can have a considerable rendering cost when resized, specially when they are complex.

Implementations

Source

impl Svg

pub fn new(handle: impl Into<Handle>) -> Svg

Creates a new Svg from the given Handle.

pub fn from_path(path: impl Into<PathBuf>) -> Svg

Creates a new Svg that will display the contents of the file at the provided path.

pub fn width(self, width: Length) -> Svg

Sets the width of the Svg.

pub fn height(self, height: Length) -> Svg

Sets the height of the Svg.

pub fn content_fit(self, content_fit: ContentFit) -> Svg

Sets the ContentFit of the Svg.

Defaults to ContentFit::Contain